==> jira-projects-plugin-4.3.2.jar: page/project/release/FilterModel-test.js <==
AJS.test.require(["com.atlassian.jira.jira-projects-plugin:release-page-assets"], function(){
    "use strict";

    var Backbone = require('backbone');
    var FilterModel = require("jira/projects/release/filter-model");

    module('JIRA.Projects.Release.FilterModel', {
        setup: function () {
            sinon.stub(JIRA.Projects.AbstractList.NavigationUtils, "navigate");
            sinon.spy(JIRA.Projects.AbstractList.FilterModel.prototype, "initialize");
            this.ver1 = new Backbone.Model({
                name: "First",
                released: true,
                archived: false,
                startDate: { formatted: "11/Jul/14" },
                releaseDate: { formatted: "19/Jul/14" },
                description: "First description"
            });
            this.ver2 = new Backbone.Model({
                name: "Second",
                released: false,
                archived: false,
                startDate: { formatted: "20/Jul/14" },
                releaseDate: { formatted: "" },
                description: "Second description"
            });
            this.ver3 = new Backbone.Model({
                name: "Third",
                released: false,
                archived: true,
                startDate: {formatted: "21/Jul/14"},
                releaseDate: {formatted: ""},
                description: "Third description"
            });

            var SubmitModelCollection = Backbone.Collection.extend({
                model: Backbone.Model
            });

            this.mockPageableCollection = {
                getPage: sinon.stub(),
                originalCollection: new SubmitModelCollection([this.ver1, this.ver2, this.ver3]),
                fullCollection: {
                    reset: sinon.stub()
                },
                resetFilter: sinon.stub(),
                on: sinon.spy()
            };

            this.filterModel = new FilterModel({
                pageableCollection: this.mockPageableCollection,
                status: "all"
            });
        },
        teardown: function () {
            JIRA.Projects.AbstractList.FilterModel.prototype.initialize.restore();
            JIRA.Projects.AbstractList.NavigationUtils.navigate.restore();
        }
    });

    test('Should call parent\'s initialize.', function () {
        sinon.assert.calledOnce(JIRA.Projects.AbstractList.FilterModel.prototype.initialize);
    });

    test('Should filter collection when adding new filter criteria.', function () {
        this.filterModel.set("status", "released");
        sinon.assert.calledOnce(this.mockPageableCollection.resetFilter);
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver1]);

        this.filterModel.set("contains", "nothing");
        sinon.assert.calledTwice(this.mockPageableCollection.resetFilter);
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, []);
    });

    test('Should filter collection when changing existing filter criteria.', function () {
        this.filterModel.set("status", "released");
        this.filterModel.set("status", "all");
        sinon.assert.calledTwice(this.mockPageableCollection.resetFilter);
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver1, this.ver2, this.ver3]);

        this.filterModel.set("contains", "text");
        this.filterModel.set("contains", "nothing");
        sinon.assert.callCount(this.mockPageableCollection.resetFilter, 4);
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, []);
    });

    test('Should filter collection when removing filter criteria.', function () {
        this.filterModel.set("status", "released");
        this.filterModel.unset("status");
        sinon.assert.calledTwice(this.mockPageableCollection.resetFilter);
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver1, this.ver2, this.ver3]);

        this.filterModel.set("contains", "nothing");
        this.filterModel.unset("contains");
        sinon.assert.callCount(this.mockPageableCollection.resetFilter, 4);
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver1, this.ver2, this.ver3]);
    });

    test('Filtering should be case insensitive.', function () {
        this.filterModel.set("contains", "FiRsT");
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver1]);

        this.filterModel.set("contains", "JUL");
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver1, this.ver2, this.ver3]);
    });

    test('Filtering should find strings in the middle of text.', function () {
        this.filterModel.set("contains", "irst");
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver1]);

        this.filterModel.set("contains", "UL");
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver1, this.ver2, this.ver3]);
    });

    test('Should filter collection by archived.', function () {
        this.filterModel.set("status", "archived");
        sinon.assert.calledOnce(this.mockPageableCollection.resetFilter);
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver3]);
    });

    test('Should filter collection by unreleased-archived.', function () {
        this.filterModel.set("status", "unreleased-archived");
        sinon.assert.calledOnce(this.mockPageableCollection.resetFilter);
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver2, this.ver3]);
    });

    test('Should filter collection by released-archived.', function () {
        this.filterModel.set("status", "released-archived");
        sinon.assert.calledOnce(this.mockPageableCollection.resetFilter);
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver1, this.ver3]);
    });
});

==> jira-projects-plugin-6.0.5.jar: page/project/release/FilterModel-test.js <==
AJS.test.require(["com.atlassian.jira.jira-projects-plugin:release-page-assets"], function(){
    "use strict";

    var Backbone = require("jira-projects-backbone");
    var FilterModel = require("jira/projects/release/filter-model");

    var NavigationUtils = require("jira/projects/abstract-list/navigation-utils");
    var ALFilterModel = require("jira/projects/abstract-list/filter-model");

    module('jira/projects/release/filter-model', {
        setup: function () {
            sinon.stub(NavigationUtils, "navigate");
            sinon.spy(ALFilterModel.prototype, "initialize");
            this.ver1 = new Backbone.Model({
                name: "First",
                released: true,
                archived: false,
                startDate: { formatted: "11/Jul/14" },
                releaseDate: { formatted: "19/Jul/14" },
                description: "First description"
            });
            this.ver2 = new Backbone.Model({
                name: "Second",
                released: false,
                archived: false,
                startDate: { formatted: "20/Jul/14" },
                releaseDate: { formatted: "" },
                description: "Second description"
            });
            this.ver3 = new Backbone.Model({
                name: "Third",
                released: false,
                archived: true,
                startDate: {formatted: "21/Jul/14"},
                releaseDate: {formatted: ""},
                description: "Third description"
            });

            var SubmitModelCollection = Backbone.Collection.extend({
                model: Backbone.Model
            });

            this.mockPageableCollection = {
                getPage: sinon.stub(),
                originalCollection: new SubmitModelCollection([this.ver1, this.ver2, this.ver3]),
                fullCollection: {
                    reset: sinon.stub()
                },
                resetFilter: sinon.stub(),
                on: sinon.spy()
            };

            this.filterModel = new FilterModel({
                pageableCollection: this.mockPageableCollection,
                status: "all"
            });
        },
        teardown: function () {
            ALFilterModel.prototype.initialize.restore();
            NavigationUtils.navigate.restore();
        }
    });

    test('Should call parent\'s initialize.', function () {
        sinon.assert.calledOnce(ALFilterModel.prototype.initialize);
    });

    test('Should filter collection when adding new filter criteria.', function () {
        this.filterModel.set("status", "released");
        sinon.assert.calledOnce(this.mockPageableCollection.resetFilter);
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver1]);

        this.filterModel.set("contains", "nothing");
        sinon.assert.calledTwice(this.mockPageableCollection.resetFilter);
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, []);
    });

    test('Should filter collection when changing existing filter criteria.', function () {
        this.filterModel.set("status", "released");
        this.filterModel.set("status", "all");
        sinon.assert.calledTwice(this.mockPageableCollection.resetFilter);
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver1, this.ver2, this.ver3]);

        this.filterModel.set("contains", "text");
        this.filterModel.set("contains", "nothing");
        sinon.assert.callCount(this.mockPageableCollection.resetFilter, 4);
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, []);
    });

    test('Should filter collection when removing filter criteria.', function () {
        this.filterModel.set("status", "released");
        this.filterModel.unset("status");
        sinon.assert.calledTwice(this.mockPageableCollection.resetFilter);
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver1, this.ver2, this.ver3]);

        this.filterModel.set("contains", "nothing");
        this.filterModel.unset("contains");
        sinon.assert.callCount(this.mockPageableCollection.resetFilter, 4);
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver1, this.ver2, this.ver3]);
    });

    test('Filtering should be case insensitive.', function () {
        this.filterModel.set("contains", "FiRsT");
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver1]);

        this.filterModel.set("contains", "JUL");
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver1, this.ver2, this.ver3]);
    });

    test('Filtering should find strings in the middle of text.', function () {
        this.filterModel.set("contains", "irst");
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver1]);

        this.filterModel.set("contains", "UL");
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver1, this.ver2, this.ver3]);
    });

    test('Should filter collection by archived.', function () {
        this.filterModel.set("status", "archived");
        sinon.assert.calledOnce(this.mockPageableCollection.resetFilter);
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver3]);
    });

    test('Should filter collection by unreleased-archived.', function () {
        this.filterModel.set("status", "unreleased-archived");
        sinon.assert.calledOnce(this.mockPageableCollection.resetFilter);
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver2, this.ver3]);
    });

    test('Should filter collection by released-archived.', function () {
        this.filterModel.set("status", "released-archived");
        sinon.assert.calledOnce(this.mockPageableCollection.resetFilter);
        sinon.assert.calledWith(this.mockPageableCollection.resetFilter, [this.ver1, this.ver3]);
    });
});
